#
# spec file for package uid_wrapper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


############################# NOTE ##################################
#
# This is a special library. You are not able to link this library.
# Do NOT create library package or a devel package!
#
############################# NOTE ##################################
Name:           uid_wrapper
Version:        1.3.1
Release:        1.3
Summary:        A wrapper for privilege seperation
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://cwrap.org/
Source0:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
Source2:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz.asc
Source3:        uid_wrapper.keyring
BuildRequires:  cmake
BuildRequires:  libcmocka-devel
BuildRequires:  pkgconf
BuildRequires:  user(nobody)
Recommends:     cmake
Recommends:     pkgconf

%description
Some projects like a file server need privilege separation to be able to switch
to the connnection user and do file operations. uid_wrapper convincingly lies
to the application, letting it believe it is operating as root and even
switching betwen UIDs and GIDs as needed.

To use it, set the following environment variables:

LD_PRELOAD=libuid_wrapper.so
UID_WRAPPER=1

This package does not have a devel package, because this project is for
development/testing.

%prep
%autosetup -p1

%build
# CMAKE_SKIP_RPATH:BOOL=OFF is need to run the tests!
%cmake \
  -DUNIT_TESTING=ON \
  -DCMAKE_SKIP_RPATH:BOOL=OFF

%make_build

%install
%cmake_install

%check
%ctest

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc AUTHORS README.md CHANGELOG
%license LICENSE
%{_libdir}/libuid_wrapper.so*
%dir %{_libdir}/cmake/uid_wrapper
%{_libdir}/cmake/uid_wrapper/uid_wrapper-config-version.cmake
%{_libdir}/cmake/uid_wrapper/uid_wrapper-config.cmake
%{_libdir}/pkgconfig/uid_wrapper.pc
%{_mandir}/man1/uid_wrapper.1%{?ext_man}

%changelog
* Thu Jun 13 2024 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.1
  * Added support to find libc via LIBC_SO define
  * Fixed uid_wrapper running with jemalloc compiled binaries
  * Fixed socket_wrapper interaction test
  * Fixed thread sanitizer on modern Linux Kernels
- Removed uid_wrapper-fix-cmocka-1.1.6+-support.patch
* Thu Mar  2 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Actually apply uid_wrapper-fix-cmocka-1.1.6+-support.patch (use
  autosetup instead of setup).
* Mon Feb 27 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix building with cmocka >= 1.1.6
  * Added uid_wrapper-fix-cmocka-1.1.6+-support.patch
* Tue Jan 17 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.0
  * Added support to interact with socket_wrapper syscall()
  * Fixed deadlocks with threads
  * Improved log output
* Thu Dec  2 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.9
  * Add support for getgroups_chk()
  * Added (de)contructor support on AIX with pragma init/finish
* Wed Apr  7 2021 Dirk Müller <dmueller@suse.com>
- remove pkgconfig and cmake directory from filelist - provided by filesystem package
* Tue Jan 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Replace system-user-nobody with user(nobody): be resilient to
  package name changes.
* Thu Mar  5 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.8
  * Fix path in pkgconfig module
  * Fix path in cmake find module
* Wed Aug 21 2019 Andreas Schneider <asn@cryptomilk.org>
- Change BR to pkgconf
- Change Requires to Recommends for pkgconf and cmake
* Tue Jul 16 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.7
  * Fix unsetting initial XIDs
- Fix running the tests
* Mon Jul 15 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.2.6
  * Fix manpage installation
  * Fix cmake-config installation
  * Fixed running with sanitizers
* Tue Jul 25 2017 asn@cryptomilk.org
- Update to version 1.2.4
  * Added deadlock workaround for glibc < 2.24
  * Fixed a possible deadlock bug if uid_wrapper is turned off
* Fri Jul 14 2017 asn@cryptomilk.org
- Update to version 1.2.3
  * Logging is always turned on now
  * Fixed a memory leak
  * Limited number of groups during fork+exec
* Thu Jul 13 2017 asn@cryptomilk.org
- Update to version 1.2.2
  * Added support for fork'ed and then exec'ed processes
  * Added support for Alpha
* Mon Mar 21 2016 asn@cryptomilk.org
- Update to version 1.2.1
  * Documented missing options.
  * Fixed a comipilation issue with -O3.
* Sun Feb 14 2016 jengelh@inai.de
- Editorial fixes to the description
* Thu Oct 29 2015 asn@cryptomilk.org
- Update to version 1.2.0
  * Added privilege checks for all set*uid and set*gid functions.
  * Added a lot more and accurate tests which work as root.
  * Fixed some minor issues
* Wed Sep  2 2015 asn@cryptomilk.org
- Update to version 1.1.1
  * Fixed getres(uid|gid) detection if unsupported.
  * Fixed the configure on Solaris
  * Added a lot more tests
* Fri Jun 26 2015 mpluskal@suse.com
- Rename rpmlintrc so that it complies with packaging guidelines
- Add rpmlintrc as source
* Thu Jun 25 2015 asn@cryptomilk.org
- Fix make install
* Mon May 11 2015 asn@cryptomilk.org
- Cleanup specfile
* Wed Jan 21 2015 asn@cryptomilk.org
- Update to version 1.1.0
  * Added support for gesresuid().
  * Added support for gesresgid().
  * Added MacOSX support.
  * Added fully working thread support.
  * Added more tests.
  * Fixed issues with older gcc versions.
* Mon Oct  6 2014 asn@cryptomilk.org
- Fix test on AArch64.
* Thu Jul 31 2014 asn@cryptomilk.org
- Update to version 1.0.2.
  * Added better logging system.
  * Added a mapnpage
  * Added build and install instructions
  * Fixed threading issue in the desctructor.
* Thu Feb 13 2014 asn@cryptomilk.org
- Initial package.
